View source: R/outliermethods.R
| adjustboxplots | R Documentation |
Adjust the boxplots bounding fences using medcouple to flag suspicious outliers.
adjustboxplots(
data,
var,
output = "outlier",
a = -4,
b = 3,
coef = 1.5,
pc = FALSE,
pcvar = NULL,
boot = FALSE
)
data |
|
var |
|
output |
|
a |
|
b |
|
coef |
|
pc |
Whether principal component analysis will be computed. Default |
pcvar |
Principal component analysis to e used for outlier detection after PCA. Default |
boot |
Whether bootstrapping will be computed. Default |
dataframe. Dataframe with or with no outliers.
Hubert M, Vandervieren E. 2008. An adjusted boxplot for skewed distributions. Computational Statistics and Data Analysis 52:5186-5201.
data("efidata")
danube <- system.file('extdata/danube.shp.zip', package='specleanr')
db <- sf::st_read(danube, quiet=TRUE)
wcd <- terra::rast(system.file('extdata/worldclim.tiff', package='specleanr'))
refdata <- pred_extract(data = efidata, raster= wcd ,
lat = 'decimalLatitude', lon= 'decimalLongitude',
colsp = "scientificName",
bbox = db,
minpts = 10)
adout <- adjustboxplots(data = refdata[["Thymallus thymallus"]], var = 'bio6', output='outlier')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.