| check_names | R Documentation |
Check species names for inconsistencies
check_names(
data,
colsp = NULL,
verbose = FALSE,
pct = 90,
merge = FALSE,
sn = FALSE,
ecosystem = FALSE,
rm_duplicates = FALSE
)
data |
|
colsp |
|
verbose |
|
pct |
|
merge |
|
sn |
|
ecosystem |
|
rm_duplicates |
|
The function produces a data set with species names corresponding with Fishase. If synonym is provided in the data set, the function will by defualt return the accepted name. However, if the synoymn is desired, then set the sn parameter to TRUE. The function also check for spellings of species names and returns a name that is closer to the one in FishBase with a particular degree of similarity set with pct parameter. pct of 1 indicates the name must 100 The user can iterate with different pct and decide if the return name is right or wrong. This function is not necessary if the species names are clean and also for other taxa.
Data frame or names of corrected or cleaned species names.
match_datasets for standardizing and binding datasets.
## Not run:
data(jdsdata)
data(efidata)
#step 1. match and bind datasets if more than one datasets
matchdata <- match_datasets(datasets = list(jds = jdsdata, efi = efidata),
lats = 'lat',
lons = 'lon',
species = c('speciesname','scientificName'),
country=c('JDS4_site_ID'),
date=c('Date', 'sampling_date'))
#clean species names to produce one dataset.
datafull <- check_names(data= matchdata, colsp='species', pct = 90, merge = TRUE)
data2col <- check_names(data = matchdata, colsp='species', pct = 90) #two columns generated
cleansp_name <- check_names(data= 'slamo trutta', pct=90) #wrong names vs FB suggestion
clean_sp_epithet <- check_names(data = 'Salmo trutta fario') #Salmo trutta will be returned
speciesepithet2 <- check_names(data = 'Salmo trutta lacustris', pct=90)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.