eif: Computes the empirical influence function for each values in...

View source: R/utils.R

eifR Documentation

Computes the empirical influence function for each values in the dataset

Description

Computes the empirical influence function for each values in the dataset

Usage

eif(x, var)

Arguments

x

Outlier checked data

var

variable of interest


specleanr documentation built on Nov. 26, 2025, 1:07 a.m.