extractMethods: List of outlier detection methods implemented in this...

View source: R/multidetect.R

extractMethodsR Documentation

List of outlier detection methods implemented in this package.

Description

List of outlier detection methods implemented in this package.

Usage

extractMethods()

Value

List of methods

Examples

extractMethods()



specleanr documentation built on Nov. 26, 2025, 1:07 a.m.