| getdata | R Documentation |
Download species records from online database.
getdata(
data,
colsp = NULL,
extent = NULL,
db = c("gbif", "vertnet", "inat"),
gbiflim = 50000,
vertlim = 1000,
inatlim = 3000,
verbose = FALSE,
warn = FALSE,
pct = 80,
sn = FALSE,
...
)
data |
|
colsp |
|
extent |
|
db |
|
gbiflim |
|
vertlim |
|
inatlim |
|
verbose |
|
warn |
|
pct |
|
sn |
|
... |
More function for species data download can be used.
See |
Note always check the validity of the species name with standard database FishBase or World Register of Marine Species. If the records are more than 50000 in GBIF, and extent can be provide to limit the download.
Lists of species records from online databases
## Not run:
gbdata <- getdata(data = 'Gymnocephalus baloni', gbiflim = 100, inatlim = 100, vertlim = 100)
#Get for two species
sp_records <- getdata(data=c('Gymnocephalus baloni', 'Hucho hucho'),
gbiflim = 100,
inatlim = 100,
vertlim = 100)
#for only two databases
sp_records_2db <- getdata(data=c('Gymnocephalus baloni', 'Hucho hucho'),
db= c('gbif','inat'),
gbiflim = 100,
inatlim = 100,
vertlim = 100)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.