View source: R/outliers_accum.R
| ggoutlieraccum | R Documentation |
Identify if enough methods are selected for the outlier detection.
ggoutlieraccum(
x,
boots = 5,
select = NULL,
ncol = 3,
linecolor = "blue",
seed = 1134,
sci = FALSE,
xlab = "Number of methods",
ylab = "Number of outliers",
scales = "free"
)
x |
|
boots |
|
select |
|
ncol |
|
linecolor |
|
seed |
|
sci |
|
xlab, ylab |
|
scales |
|
ggplot2 output with cumulative number of outliers and number of methods used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.