| handle_true_errors | R Documentation |
Catch errors during methods implementation.
handle_true_errors(
func,
fname = NULL,
spname = NULL,
verbose = FALSE,
warn = FALSE,
silence_true_errors = TRUE
)
func |
Outlier detection function |
fname |
function name for messaging or warning identification. |
spname |
species name being handled |
verbose |
whether to return messages or not. Default |
warn |
whether to return warning or not. Default TRUE. |
silence_true_errors |
show execution errors and therefore for multiple species the code will break if one of the methods fails to execute. |
Handle errors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.