View source: R/similaritytests.R
| ocindex | R Documentation |
Identifies absolute outliers and their proportions for a single species.
ocindex(
x,
sp = NULL,
threshold = NULL,
absolute = FALSE,
props = FALSE,
warn = FALSE,
autothreshold = FALSE
)
x |
|
sp |
|
threshold |
|
absolute |
|
props |
|
warn |
|
autothreshold |
|
vector or dataframe of absolute outliers, best outlier detection method or data frame of absolute outliers and their
proportions
data(efidata)
danube <- system.file('extdata/danube.shp.zip', package='specleanr')
db <- sf::st_read(danube, quiet=TRUE)
wcd <- terra::rast(system.file('extdata/worldclim.tiff', package = "specleanr"))
extdf <- pred_extract(data = efidata, raster = wcd,
lat = 'decimalLatitude', lon = 'decimalLongitude',
colsp = "scientificName",
list = TRUE,verbose = FALSE,
minpts = 6,merge = FALSE)#basin removed
#outlier detection
outliersdf <- multidetect(data = extdf, output='outlier', var = 'bio6',
exclude = c('x','y'), multiple = TRUE,
methods = c('mixediqr', "iqr", "mahal", "iqr", "logboxplot"))
ociss <- ocindex(x = outliersdf, sp= 1, threshold = 0.2, absolute = TRUE)#
#No outliers detected in more than two methods
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.