| pcboot | R Documentation |
To package both principal component analysis and bootstrapping.
pcboot(pb, var, pc, boot, pcvar)
pb |
the principal component or bootstrapped data |
var |
The variable of concern, which is vital for univariate outlier detection methods |
pc |
Whether principal component analysis will be computed. Default |
boot |
Whether bootstrapping will be computed. Default |
pcvar |
Principal component analysis to e used for outlier detection after PCA. Default |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.