| pred_extract | R Documentation |
Preliminary data cleaning including removing duplicates, records outside a particular basin, and NAs.
pred_extract(
data,
raster,
lat = NULL,
lon = NULL,
bbox = NULL,
colsp,
minpts = 10,
mp = TRUE,
rm_duplicates = TRUE,
na.rm = TRUE,
na.inform = FALSE,
list = TRUE,
merge = FALSE,
verbose = FALSE,
warn = FALSE,
coords = FALSE
)
data |
|
raster |
|
lat, lon |
|
bbox |
|
colsp |
|
minpts |
|
mp |
|
rm_duplicates |
|
na.rm |
|
na.inform |
|
list |
|
merge |
|
verbose |
|
warn |
|
coords |
|
dataframe or list of precleaned data sets for single or multiple species.
data("efidata")
danube <- system.file('extdata/danube.shp.zip', package='specleanr')
danubebasin <- sf::st_read(danube, quiet=TRUE)
#Get environmental data
worldclim <- terra::rast(system.file('extdata/worldclim.tiff', package='specleanr'))
referencedata <- pred_extract(data = efidata,
raster= worldclim ,
lat ="decimalLatitude",
lon = 'decimalLongitude',
colsp = 'scientificName',
bbox = danubebasin,
list= TRUE, #list will be generated for all species
minpts = 7, merge=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.