| search_threshold | R Documentation |
Determine the threshold using Locally estimated or weighted Scatterplot Smoothing.
search_threshold(
data,
outliers,
sp = NULL,
plotsetting = list(plot = FALSE, group = NULL),
var_col = NULL,
warn = FALSE,
verbose = FALSE,
cutoff,
tloss = seq(0.1, 1, 0.1)
)
data |
|
outliers |
|
sp |
|
plotsetting |
|
var_col |
|
warn |
|
verbose |
|
cutoff |
|
tloss |
|
Returns numeric of most suitable threshold at globalmaxima or localmaxima of the loess smoothing.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.