Learn R Programming

specleanr (version 1.0.0)

show,datacleaner-method: set method for displaying output details after outlier detection.

Description

set method for displaying output details after outlier detection.

Usage

# S4 method for datacleaner
show(object)

Value

prints the datacleaner class for this package.

Arguments

object

The data model for outlier detection.