View source: R/outliermethods.R
| xglosh | R Documentation |
Global-Local Outlier Score from Hierarchies
xglosh(
data,
k,
output,
exclude = NULL,
metric = "manhattan",
mode = "soft",
pc = FALSE,
boot = FALSE,
var,
pcvar = NULL
)
data |
Data frame of species records with environmental data. |
k |
The size of the neighborhood |
output |
Either clean: for data frame with no suspicious outliers or outlier: to return dataframe with only outliers. |
exclude |
Exclude variables that should not be considered in the fitting the one class model, for example x and y columns or latitude/longitude or any column that the user doesn't want to consider. |
metric |
The different metric distances to compute the distances among the environmental predictors. See |
mode |
This includes |
pc |
Whether principal component analysis will be computed. Default |
boot |
Whether bootstrapping will be computed. Default |
var |
The variable of concern, which is vital for univariate outlier detection methods |
pcvar |
Principal component analysis to e used for outlier detection after PCA. Default |
Dataframe with or with no outliers.
Campello, Ricardo JGB, Davoud Moulavi, Arthur Zimek, and Joerg Sander. Hierarchical density estimates for data clustering, visualization, and outlier detection. ACM Transactions on Knowledge Discovery from Data (TKDD) 10, no. 1 (2015). doi:10.1145/2733381
Hahsler M, Piekenbrock M (2022). dbscan: Density-Based Spatial Clustering of Applications with Noise (DBSCAN) and Related Algorithms. R package version 1.1-11, <https://CRAN.R-project.org/package=dbscan>
data("efidata")
danube <- system.file('extdata/danube.shp.zip', package='specleanr')
db <- sf::st_read(danube, quiet=TRUE)
wcd <- terra::rast(system.file('extdata/worldclim.tiff', package='specleanr'))
refdata <- pred_extract(data = efidata, raster= wcd ,
lat = 'decimalLatitude',
lon= 'decimalLongitude',
colsp = "scientificName",
bbox = db,
minpts = 10)
gloshout <- xglosh(data = refdata[["Thymallus thymallus"]], exclude = c("x", "y"),
output='outlier', metric ='manhattan', k = 3,
mode = "soft")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.