Learn R Programming

specleanr (version 1.0.0)

efidata: EFIPLUS data used to develop ecological sensitivity parameters for riverine species in European streams and rivers.

Description

A tibble

Usage

data(efidata)

Arguments

Format

A tibble 99 rows and 23 columns.

Details

BQEs sensitivity to global/climate change in European rivers: implications for reference conditions and pressure-impact-recovery chains (Logez et al. 2012). An extract has been made for usage in this package but for more information write to ihg@boku.ac.at

References

Logez M, Belliard J, Melcher A, Kremser H, Pletterbauer F, Schmutz S, Gorges G, Delaigue O, Pont D. 2012. Deliverable D5.1-3: BQEs sensitivity to global/climate change in European rivers: implications for reference conditions and pressure-impact-recovery chains.

Examples

Run this code

data("efidata")
efidata

Run the code above in your browser using DataLab