powered by
Checks for geographic ranges from FishBase
geo_ranges( data, colsp = NULL, verbose = FALSE, pct = 90, sn = FALSE, warn = FALSE, synonym = fishbase(tables = "synonym"), ranges = fishbase(tables = "ranges") )
Dataframe with geographical corrected ranges for species from FishBase.
Dataframe or vector to retrieve ranges from FishBase.
Column with species names from the data set.
TRUE and messages will show. Default FALSE:
The percentage similarity of species names during standardization from FishBase.
TRUE and synonyms will be generated and not accepted ones. Default is FALSE, where species accepted names will be produced.
FALSE, not to generate warnings and TRUE for warnings. Default is FALSE:
A standard database for species synonym names from FishBase. See FishBase for more information.
A standard database for ecological ranges from FishBase. See FishBase for more information.
if (FALSE) { gr <- geo_ranges(data= "Lates niloticus") }
Run the code above in your browser using DataLab