| kdat | R Documentation |
A tibble data with k constants for sequential fences method.
data(kdat)
A tibble 101 rows and 2 columns.
k constants fro flagging outliers with several chnages in the fences.
Schwertman NC, de Silva R. 2007. Identifying outliers with sequential fences. Computational Statistics and Data Analysis 51:3800–3810.
data("kdat")
kdat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.